@@ -1,13 +1,14 @@
-// { dg-require-namedlocale "" }
+// { dg-require-namedlocale "de_DE" }
 
 // 2001-11-19 Benjamin Kosnik  <bkoz@redhat.com>
 
-// Copyright (C) 2001, 2002, 2003, 2004, 2005 Free Software Foundation
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2009, 2010
+// Free Software Foundation
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
 // terms of the GNU General Public License as published by the
-// Free Software Foundation; either version 2, or (at your option)
+// Free Software Foundation; either version 3, or (at your option)
 // any later version.
 
 // This library is distributed in the hope that it will be useful,
@@ -16,9 +17,8 @@
 // GNU General Public License for more details.
 
 // You should have received a copy of the GNU General Public License along
-// with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-// USA.
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
 
 // 22.2.2.2.1  num_put members
 
@@ -62,10 +62,9 @@ void test01()
 
   // bool, simple
   iterator_type os_it00 = oss.rdbuf();
-  iterator_type os_it01 = np.put(os_it00, oss, L'+', b1);
+  np.put(os_it00, oss, L'+', b1);
   result1 = oss.str();
   VERIFY( result1 == L"1" );
-  //  VERIFY( os_it00 != os_it01 );
 
   oss.str(empty);
   np.put(oss.rdbuf(), oss, L'+', b0);
@@ -134,7 +133,7 @@ void test01()
   result1 = oss.str();
   VERIFY( result1 == L"0" );
 
-  // const void
+  // const void*
   oss.str(empty);
   oss.clear();
   np.put(oss.rdbuf(), oss, L'+', cv);
