@@ -1,13 +1,13 @@
 // 981208 bkoz test functionality of basic_stringbuf for char_type == wchar_t
 
 // Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
-// 2006, 2007
+// 2006, 2007, 2009, 2010
 // Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
 // terms of the GNU General Public License as published by the
-// Free Software Foundation; either version 2, or (at your option)
+// Free Software Foundation; either version 3, or (at your option)
 // any later version.
 
 // This library is distributed in the hope that it will be useful,
@@ -16,9 +16,8 @@
 // GNU General Public License for more details.
 
 // You should have received a copy of the GNU General Public License along
-// with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-// USA.
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
 
 #include <sstream>
 #include <testsuite_hooks.h>
@@ -34,14 +33,13 @@ std::wstringbuf strb_03(str_03, std::ios_base::out);
 void test04() 
 {
   bool test __attribute__((unused)) = true;
-  std::streamoff  		strmof_1(-1), strmof_2;
   typedef std::wstringbuf::int_type int_type;
   typedef std::wstringbuf::traits_type traits_type;
 
   // GET
-  strmof_1 = strb_01.in_avail();
-  strmof_2 = strb_02.in_avail();
-  strmof_1 = strb_03.in_avail(); 
+  strb_01.in_avail();
+  strb_02.in_avail();
+  strb_03.in_avail(); 
 
   strb_01.sbumpc();
   strb_02.sbumpc();
